@@ -61,6 +61,9 @@ class BaseAssembly:
 
     NON_SUB_CHARS = ',@#$~!?[]{}|'  # Add as needed
 
+    def fix_up_special_opcodes(self, nmatch):
+        return nmatch
+
     def find_opcode_for_text(self, text: str, assembler):
         '''Find the one opcode that best matches this line of text
 
@@ -78,6 +81,8 @@ class BaseAssembly:
         # Ignorable whitespace
         nmatch = self.remove_unneeded_whitespace(text)
 
+        nmatch = self.fix_up_special_opcodes(nmatch)
+
         possibles = []
         possibles_info = []
         longest_first_frag = 0
@@ -160,10 +165,14 @@ class BaseAssembly:
             # If not, we might have the address defined. If so, pick based on value.
 
             if '>' in text:
+                # Developer says two-bytes
                 sz = 2
             elif '<' in text:
+                # Developer says one-byte
                 sz = 1
             else:
+                # We might be able to figure out what it is if the value is
+                # defined already
                 targ = None
                 for p in possibles_info:
                     for k in p:
@@ -180,6 +189,7 @@ class BaseAssembly:
                     else:
                         sz = 2
                 except Exception:
+                    # Can't tell if this is one or two bytes ... go with 2
                     sz = 2
 
             for i in range(len(possibles) - 1, -1, -1):
@@ -193,7 +203,14 @@ class BaseAssembly:
 
             return (possibles[0], possibles_info[0])
 
-        raise AssemblyException('Multiple Matches')
+        # Their might be multiple opcodes with the same mnemonics. In that case,
+        # just pick the first
+
+        g = possibles[0]
+        for p in possibles:
+            if p.mnemonic != g.mnemonic:
+                raise AssemblyException('Multiple Matches')
+        return(possibles[i], possibles_info[i])
 
     def fill_in_opcode(self, _text, asm, address, op, pass_number):
         '''
